==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicPanelUI.c <==
// public class javax.swing.plaf.basic.BasicPanelUI

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class d7f8ed72eea34302 javax_swing_plaf_PanelUI
// @dep_class 2d7c79ec306a699e javax_swing_plaf_basic_BasicPanelUI

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_JComponent
// @dep_header javax_swing_plaf_basic_BasicPanelUI

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/JComponent.h"
#include "javax/swing/plaf/basic/BasicPanelUI.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static javax.swing.plaf.ComponentUI createUI(javax.swing.JComponent)
//

static _jc_linenum _jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$createUI$32e25151aaddad9d[];

static const unsigned char _jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$createUI$32e25151aaddad9d[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$param_types$createUI$32e25151aaddad9d[] = {
	&_jc_javax_swing_JComponent$type
};

_jc_method _jc_javax_swing_plaf_basic_BasicPanelUI$method_info$createUI$32e25151aaddad9d = {
	.name=			"createUI",
	.signature=		"(Ljavax/swing/JComponent;)Ljavax/swing/plaf/ComponentUI;",
	.class=			&_jc_javax_swing_plaf_basic_BasicPanelUI$type,
	.param_types=		&_jc_javax_swing_plaf_basic_BasicPanelUI$param_types$createUI$32e25151aaddad9d,
	.return_type=		&_jc_javax_swing_plaf_ComponentUI$type,
	.param_ptypes=		&_jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$createUI$32e25151aaddad9d,
	.signature_hash=	_JC_JLONG(0x32e25151aaddad9d),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC,
	.function=		&_jc_javax_swing_plaf_basic_BasicPanelUI$method$createUI$32e25151aaddad9d,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$createUI$32e25151aaddad9d
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_plaf_basic_BasicPanelUI, createUI$32e25151aaddad9d);

_jc_javax_swing_plaf_ComponentUI$object *
_jc_javax_swing_plaf_basic_BasicPanelUI$method$createUI$32e25151aaddad9d(_jc_env *const env, _jc_javax_swing_JComponent$object *param0)
{
	struct _jc_javax_swing_JComponent$object *r0;
	struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *r1;

	r0 = param0;
	_JC_LINE_NUMBER(49);				// 0
	r1 = _JC_NEW(env, javax_swing_plaf_basic_BasicPanelUI);
	return r1;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_plaf_basic_BasicPanelUI$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_plaf_basic_BasicPanelUI$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_plaf_basic_BasicPanelUI$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_plaf_basic_BasicPanelUI, _init$52f4ad9f2989aeee);

void
_jc_javax_swing_plaf_basic_BasicPanelUI$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_plaf_basic_BasicPanelUI$object *this)
{
	struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(45);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public void installUI(javax.swing.JComponent)
//

static _jc_linenum _jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$installUI$ddb69f0251b0939f[];

static const unsigned char _jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$installUI$ddb69f0251b0939f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$param_types$installUI$ddb69f0251b0939f[] = {
	&_jc_javax_swing_JComponent$type
};

_jc_method _jc_javax_swing_plaf_basic_BasicPanelUI$method_info$installUI$ddb69f0251b0939f = {
	.name=			"installUI",
	.signature=		"(Ljavax/swing/JComponent;)V",
	.class=			&_jc_javax_swing_plaf_basic_BasicPanelUI$type,
	.param_types=		&_jc_javax_swing_plaf_basic_BasicPanelUI$param_types$installUI$ddb69f0251b0939f,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$installUI$ddb69f0251b0939f,
	.signature_hash=	_JC_JLONG(0xddb69f0251b0939f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_plaf_basic_BasicPanelUI$method$installUI$ddb69f0251b0939f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_plaf_basic_BasicPanelUI$vtable, javax_swing_plaf_basic_BasicPanelUI.installUI$ddb69f0251b0939f) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$installUI$ddb69f0251b0939f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_plaf_basic_BasicPanelUI, installUI$ddb69f0251b0939f);

void
_jc_javax_swing_plaf_basic_BasicPanelUI$method$installUI$ddb69f0251b0939f(_jc_env *const env, _jc_javax_swing_plaf_basic_BasicPanelUI$object *this, _jc_javax_swing_JComponent$object *param0)
{
	struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *r0;
	struct _jc_javax_swing_JComponent$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(55);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_plaf_basic_BasicPanelUI$methods[] = {
	&_jc_javax_swing_plaf_basic_BasicPanelUI$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_plaf_basic_BasicPanelUI$method_info$createUI$32e25151aaddad9d,
	&_jc_javax_swing_plaf_basic_BasicPanelUI$method_info$installUI$ddb69f0251b0939f
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_2[] = {
	&_jc_javax_swing_plaf_PanelUI$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_28[] = {
	&_jc_javax_swing_plaf_ComponentUI$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_30[] = {
	&_jc_javax_swing_plaf_basic_BasicPanelUI$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[2]=	_jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_2,
	[28]=	_jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_28,
	[30]=	_jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_30,
	[113]=	_jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_plaf_basic_BasicPanelUI$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/swing/JComponent",	_JC_JLONG(0x6c83b58ef8abc63e) },
	{ "javax/swing/plaf/ComponentUI",	_JC_JLONG(0x9f393451fe8ae81c) },
	{ "javax/swing/plaf/PanelUI",	_JC_JLONG(0xd7f8ed72eea34302) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_plaf_basic_BasicPanelUI$vtype _jc_javax_swing_plaf_basic_BasicPanelUI$type = {
    .type= {
	.name=			"javax/swing/plaf/basic/BasicPanelUI",
	.superclass=		&_jc_javax_swing_plaf_PanelUI$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		22,
		.hash=			_JC_JLONG(0x2d7c79ec306a699e),
		.source_file=		"BasicPanelUI.java",
		.instance_size=		sizeof(_jc_javax_swing_plaf_basic_BasicPanelUI$refs) + sizeof(_jc_javax_swing_plaf_basic_BasicPanelUI$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_swing_plaf_basic_BasicPanelUI$methods) / sizeof(*_jc_javax_swing_plaf_basic_BasicPanelUI$methods),
		.methods=		_jc_javax_swing_plaf_basic_BasicPanelUI$methods,
		.instanceof_hash_table=	_jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_swing_plaf_basic_BasicPanelUI$class_depends) / sizeof(*_jc_javax_swing_plaf_basic_BasicPanelUI$class_depends),
		.class_depends=		_jc_javax_swing_plaf_basic_BasicPanelUI$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_plaf_ComponentUI= {
	    .contains$59856e8380ce73c7=
		&_jc_javax_swing_plaf_ComponentUI$method$contains$59856e8380ce73c7,
	    .getAccessibleChild$f4df0dece809e52b=
		&_jc_javax_swing_plaf_ComponentUI$method$getAccessibleChild$f4df0dece809e52b,
	    .getAccessibleChildrenCount$d6aace9f5491b2f1=
		&_jc_javax_swing_plaf_ComponentUI$method$getAccessibleChildrenCount$d6aace9f5491b2f1,
	    .getMaximumSize$53a1753c72ad50a1=
		&_jc_javax_swing_plaf_ComponentUI$method$getMaximumSize$53a1753c72ad50a1,
	    .getMinimumSize$0409118567fd57f9=
		&_jc_javax_swing_plaf_ComponentUI$method$getMinimumSize$0409118567fd57f9,
	    .getPreferredSize$c70d4f812111358c=
		&_jc_javax_swing_plaf_ComponentUI$method$getPreferredSize$c70d4f812111358c,
	    .installUI$ddb69f0251b0939f=			// overridden
		&_jc_javax_swing_plaf_basic_BasicPanelUI$method$installUI$ddb69f0251b0939f,
	    .paint$772d1272d1c3f8bb=
		&_jc_javax_swing_plaf_ComponentUI$method$paint$772d1272d1c3f8bb,
	    .uninstallUI$cca6f1762c3c689e=
		&_jc_javax_swing_plaf_ComponentUI$method$uninstallUI$cca6f1762c3c689e,
	    .update$65231308d056d80d=
		&_jc_javax_swing_plaf_ComponentUI$method$update$65231308d056d80d,
	},
	.javax_swing_plaf_PanelUI= {
	},
	.javax_swing_plaf_basic_BasicPanelUI= {
	    .installUI$ddb69f0251b0939f=
		&_jc_javax_swing_plaf_basic_BasicPanelUI$method$installUI$ddb69f0251b0939f,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicPanelUI.c <==
// public class javax.swing.plaf.basic.BasicPanelUI

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class d7f8ed72eea34302 javax_swing_plaf_PanelUI
// @dep_class 2d7c79ec306a699e javax_swing_plaf_basic_BasicPanelUI

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_swing_JComponent
// @dep_header javax_swing_plaf_basic_BasicPanelUI

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/swing/JComponent.h"
#include "javax/swing/plaf/basic/BasicPanelUI.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static javax.swing.plaf.ComponentUI createUI(javax.swing.JComponent)
//

static _jc_linenum _jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$createUI$32e25151aaddad9d[];

static const unsigned char _jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$createUI$32e25151aaddad9d[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$param_types$createUI$32e25151aaddad9d[] = {
	&_jc_javax_swing_JComponent$type
};

_jc_method _jc_javax_swing_plaf_basic_BasicPanelUI$method_info$createUI$32e25151aaddad9d = {
	.name=			"createUI",
	.signature=		"(Ljavax/swing/JComponent;)Ljavax/swing/plaf/ComponentUI;",
	.class=			&_jc_javax_swing_plaf_basic_BasicPanelUI$type,
	.param_types=		&_jc_javax_swing_plaf_basic_BasicPanelUI$param_types$createUI$32e25151aaddad9d,
	.return_type=		&_jc_javax_swing_plaf_ComponentUI$type,
	.param_ptypes=		&_jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$createUI$32e25151aaddad9d,
	.signature_hash=	_JC_JLONG(0x32e25151aaddad9d),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC,
	.function=		&_jc_javax_swing_plaf_basic_BasicPanelUI$method$createUI$32e25151aaddad9d,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$createUI$32e25151aaddad9d
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_plaf_basic_BasicPanelUI, createUI$32e25151aaddad9d);

_jc_javax_swing_plaf_ComponentUI$object * _JC_JCNI_ATTR
_jc_javax_swing_plaf_basic_BasicPanelUI$method$createUI$32e25151aaddad9d(_jc_env *const env, _jc_javax_swing_JComponent$object *param0)
{
	struct _jc_javax_swing_JComponent$object *r0;
	struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *r1;

	r0 = param0;
	_JC_LINE_NUMBER(49);				// 0
	r1 = _JC_NEW(env, javax_swing_plaf_basic_BasicPanelUI);
	return r1;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_swing_plaf_basic_BasicPanelUI$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_swing_plaf_basic_BasicPanelUI$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_plaf_basic_BasicPanelUI$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_plaf_basic_BasicPanelUI, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_javax_swing_plaf_basic_BasicPanelUI$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_swing_plaf_basic_BasicPanelUI$object *this)
{
	struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(45);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public void installUI(javax.swing.JComponent)
//

static _jc_linenum _jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$installUI$ddb69f0251b0939f[];

static const unsigned char _jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$installUI$ddb69f0251b0939f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$param_types$installUI$ddb69f0251b0939f[] = {
	&_jc_javax_swing_JComponent$type
};

_jc_method _jc_javax_swing_plaf_basic_BasicPanelUI$method_info$installUI$ddb69f0251b0939f = {
	.name=			"installUI",
	.signature=		"(Ljavax/swing/JComponent;)V",
	.class=			&_jc_javax_swing_plaf_basic_BasicPanelUI$type,
	.param_types=		&_jc_javax_swing_plaf_basic_BasicPanelUI$param_types$installUI$ddb69f0251b0939f,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_swing_plaf_basic_BasicPanelUI$param_ptypes$installUI$ddb69f0251b0939f,
	.signature_hash=	_JC_JLONG(0xddb69f0251b0939f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_swing_plaf_basic_BasicPanelUI$method$installUI$ddb69f0251b0939f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_swing_plaf_basic_BasicPanelUI$vtable, javax_swing_plaf_basic_BasicPanelUI.installUI$ddb69f0251b0939f) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_swing_plaf_basic_BasicPanelUI$linenum_table$installUI$ddb69f0251b0939f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_swing_plaf_basic_BasicPanelUI, installUI$ddb69f0251b0939f);

void _JC_JCNI_ATTR
_jc_javax_swing_plaf_basic_BasicPanelUI$method$installUI$ddb69f0251b0939f(_jc_env *const env, _jc_javax_swing_plaf_basic_BasicPanelUI$object *this, _jc_javax_swing_JComponent$object *param0)
{
	struct _jc_javax_swing_plaf_basic_BasicPanelUI$object *r0;
	struct _jc_javax_swing_JComponent$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(55);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_swing_plaf_basic_BasicPanelUI$methods[] = {
	&_jc_javax_swing_plaf_basic_BasicPanelUI$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_swing_plaf_basic_BasicPanelUI$method_info$createUI$32e25151aaddad9d,
	&_jc_javax_swing_plaf_basic_BasicPanelUI$method_info$installUI$ddb69f0251b0939f
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_2[] = {
	&_jc_javax_swing_plaf_PanelUI$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_28[] = {
	&_jc_javax_swing_plaf_ComponentUI$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_30[] = {
	&_jc_javax_swing_plaf_basic_BasicPanelUI$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[2]=	_jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_2,
	[28]=	_jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_28,
	[30]=	_jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_30,
	[101]=	_jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_swing_plaf_basic_BasicPanelUI$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/swing/JComponent",	_JC_JLONG(0xc84352ee73c7cec1) },
	{ "javax/swing/plaf/ComponentUI",	_JC_JLONG(0x9f393451fe8ae81c) },
	{ "javax/swing/plaf/PanelUI",	_JC_JLONG(0xd7f8ed72eea34302) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_swing_plaf_basic_BasicPanelUI$vtype _jc_javax_swing_plaf_basic_BasicPanelUI$type = {
    .type= {
	.name=			"javax/swing/plaf/basic/BasicPanelUI",
	.superclass=		&_jc_javax_swing_plaf_PanelUI$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		22,
		.hash=			_JC_JLONG(0x2d7c79ec306a699e),
		.source_file=		"BasicPanelUI.java",
		.instance_size=		sizeof(_jc_javax_swing_plaf_basic_BasicPanelUI$refs) + sizeof(_jc_javax_swing_plaf_basic_BasicPanelUI$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_javax_swing_plaf_basic_BasicPanelUI$methods) / sizeof(*_jc_javax_swing_plaf_basic_BasicPanelUI$methods),
		.methods=		_jc_javax_swing_plaf_basic_BasicPanelUI$methods,
		.instanceof_hash_table=	_jc_javax_swing_plaf_basic_BasicPanelUI$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_swing_plaf_basic_BasicPanelUI$class_depends) / sizeof(*_jc_javax_swing_plaf_basic_BasicPanelUI$class_depends),
		.class_depends=		_jc_javax_swing_plaf_basic_BasicPanelUI$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_swing_plaf_ComponentUI= {
	    .contains$59856e8380ce73c7=
		&_jc_javax_swing_plaf_ComponentUI$method$contains$59856e8380ce73c7,
	    .getAccessibleChild$f4df0dece809e52b=
		&_jc_javax_swing_plaf_ComponentUI$method$getAccessibleChild$f4df0dece809e52b,
	    .getAccessibleChildrenCount$d6aace9f5491b2f1=
		&_jc_javax_swing_plaf_ComponentUI$method$getAccessibleChildrenCount$d6aace9f5491b2f1,
	    .getMaximumSize$53a1753c72ad50a1=
		&_jc_javax_swing_plaf_ComponentUI$method$getMaximumSize$53a1753c72ad50a1,
	    .getMinimumSize$0409118567fd57f9=
		&_jc_javax_swing_plaf_ComponentUI$method$getMinimumSize$0409118567fd57f9,
	    .getPreferredSize$c70d4f812111358c=
		&_jc_javax_swing_plaf_ComponentUI$method$getPreferredSize$c70d4f812111358c,
	    .installUI$ddb69f0251b0939f=			// overridden
		&_jc_javax_swing_plaf_basic_BasicPanelUI$method$installUI$ddb69f0251b0939f,
	    .paint$772d1272d1c3f8bb=
		&_jc_javax_swing_plaf_ComponentUI$method$paint$772d1272d1c3f8bb,
	    .uninstallUI$cca6f1762c3c689e=
		&_jc_javax_swing_plaf_ComponentUI$method$uninstallUI$cca6f1762c3c689e,
	    .update$65231308d056d80d=
		&_jc_javax_swing_plaf_ComponentUI$method$update$65231308d056d80d,
	},
	.javax_swing_plaf_PanelUI= {
	},
	.javax_swing_plaf_basic_BasicPanelUI= {
	    .installUI$ddb69f0251b0939f=
		&_jc_javax_swing_plaf_basic_BasicPanelUI$method$installUI$ddb69f0251b0939f,
	},
    }
};
